Upgrade to Math::BigInt 1.66.
[p5sagit/p5-mst-13.2.git] / perl.h
diff --git a/perl.h b/perl.h
index 1d740ec..73aad3c 100644 (file)
--- a/perl.h
+++ b/perl.h
@@ -247,9 +247,8 @@ register struct op *Perl_op asm(stringify(OP_IN_REGISTER));
 #define SOFT_CAST(type)        (type)
 #endif
 
-/* Only these byteorders are really known and tested. */
-#if !(BYTEORDER == 0x1234 || BYTEORDER == 0x12345678 || BYTEORDER == 0x4321 || BYTEORDER == 0x87654321)
-#   error "UNKNOWN BYTEORDER!"
+#ifndef BYTEORDER  /* Should never happen -- byteorder is in config.h */
+#   define BYTEORDER 0x1234
 #endif
 
 /* Overall memory policy? */
@@ -714,9 +713,14 @@ int usleep(unsigned int);
 #endif
 
 /* sockatmark() is so new (2001) that many places might have it hidden
* behind some -D_BLAH_BLAH_SOURCE guard. */
 #if defined(HAS_SOCKATMARK) && !defined(HAS_SOCKATMARK_PROTO)
+# if defined(__THROW) && defined(__GLIBC__)
+int sockatmark(int) __THROW;
+# else
 int sockatmark(int);
+# endif
 #endif
 
 #ifdef SETERRNO
@@ -3848,7 +3852,7 @@ typedef struct am_table_short AMTS;
 #define IN_LOCALE_COMPILETIME  (PL_hints & HINT_LOCALE)
 
 #define IN_LOCALE \
-       (PL_curcop == &PL_compiling ? IN_LOCALE_COMPILETIME : IN_LOCALE_RUNTIME)
+       (IN_PERL_COMPILETIME ? IN_LOCALE_COMPILETIME : IN_LOCALE_RUNTIME)
 
 #define STORE_NUMERIC_LOCAL_SET_STANDARD() \
        bool was_local = PL_numeric_local && IN_LOCALE; \
@@ -714,9 +713,14 @@ int usleep(unsigned int);
 
 /* sockatmark() is so new (2001) that many places might have it hidden
- * behind some -D_BLAH_BLAH_SOURCE guard. */
+ * behind some -D_BLAH_BLAH_SOURCE guard.  The __THROW magic is required
+ * e.g. in Gentoo, see http://bugs.gentoo.org/show_bug.cgi?id=12605 */
 #if defined(HAS_SOCKATMARK) && !defined(HAS_SOCKATMARK_PROTO)